@@ -99,7 +99,7 @@ fn fold_expr(expr: &syn::Expr) -> Option<u128> {
             }
         }
         Expr::Paren(syn::ExprParen { expr, .. }) | Expr::Group(syn::ExprGroup { expr, .. }) => {
-            fold_expr(&expr)
+            fold_expr(expr)
         }
         _ => None,
     }
@@ -151,13 +151,18 @@ fn inferred_value(type_name: &Ident, previous_variants: &[Ident], repr: &Ident)
 }
 
 fn infer_values(flags: &mut [Flag], type_name: &Ident, repr: &Ident) {
-    let mut previous_variants: Vec<Ident> = flags.iter()
+    let mut previous_variants: Vec<Ident> = flags
+        .iter()
         .filter(|flag| !flag.value.is_inferred())
-        .map(|flag| flag.name.clone()).collect();
+        .map(|flag| flag.name.clone())
+        .collect();
 
     for flag in flags {
         if let FlagValue::Inferred(ref mut variant) = flag.value {
-            variant.discriminant = Some((<Token![=]>::default(), inferred_value(type_name, &previous_variants, repr)));
+            variant.discriminant = Some((
+                <Token![=]>::default(),
+                inferred_value(type_name, &previous_variants, repr),
+            ));
             previous_variants.push(flag.name.clone());
         }
     }
